@@ -1,7 +1,7 @@
 from flask_admin import Admin
 from flask_admin.base import AdminIndexView
 from flask_admin.contrib import sqla
-from flask_simplelogin import login_required
+# from flask_simplelogin import login_required
 from werkzeug.security import generate_password_hash
 
 from hiddifypanel.panel.database import db
